#
# spec file for package nfsidmap
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nfsidmap
Version:        0.26
Release:        lp151.4.3.1
Summary:        NFSv4 ID Mapping Library
License:        BSD-3-Clause
Group:          Productivity/Networking/NFS
Url:            http://nfs.sourceforge.net

Source0:        https://fedorapeople.org/~steved/libnfsidmap/%{version}/libnfsidmap-%{version}.tar.bz2
Source1:        nfsv4.schema
Patch0:         fix-prototype.patch
Patch1:         libnfsidmap-export-symbols.patch
Patch2:         0001-libnfsidmap-add-options-to-aid-id-mapping-in-multi-d.patch
Patch3:         0002-nss_gss_princ_to_ids-and-nss_gss_princ_to_grouplist-.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libtool
BuildRequires:  openldap2-devel
BuildRequires:  pkg-config
BuildRequires:  tcpd-devel

%description
In NFSv4, identities of users are conveyed by names rather than user ID
and group ID. Both the NFS server and client code in the kernel need to
translate these to numeric IDs.

%package devel
Summary:        NFSv4 ID Mapping Library development libraries
Group:          Development/Libraries/C and C++
Requires:       nfsidmap = %version

%description devel
In NFSv4, identities of users are conveyed by names rather than user ID
and group ID. Both the NFS server and client code in the kernel need to
translate these to numeric IDs.

%prep
%setup -q -n libnfsidmap-%version
%patch0 -p0
%patch1
%patch2 -p1
%patch3 -p1
cp %{S:1} .

%build
autoreconf -fiv
export CFLAGS="$RPM_OPT_FLAGS -DLDAP_DEPRECATED -DENABLE_LDAP"
%configure --disable-static --with-pic --with-pluginpath=%_libdir/libnfsidmap
%{__make} %{?_smp_mflags}

%check
make check

%install
make DESTDIR=$RPM_BUILD_ROOT install
%{__rm} -f %{buildroot}%{_libdir}/*.la
%{__rm} -f %{buildroot}%{_libdir}/libnfsidmap/*.la

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README nfsv4.schema
%{_libdir}/libnfsidmap/
%{_libdir}/libnfsidmap.so.0*
%{_mandir}/man?/*

%files devel
%defattr(-,root,root)
%{_libdir}/libnfsidmap.so
%{_includedir}/*.h
%{_libdir}/pkgconfig/libnfsidmap.pc

%changelog
* Tue Aug  7 2018 nfbrown@suse.com
- 0001-libnfsidmap-add-options-to-aid-id-mapping-in-multi-d.patch
  0002-nss_gss_princ_to_ids-and-nss_gss_princ_to_grouplist-.patch
  Improve support for SAMBA+AD
  (bsc#1098217)
* Thu Mar  5 2015 p.drouand@gmail.com
- Update to version 0.26
  * No changelog available
- Point download Url to new home
- Remove depreciated AUTHORS section
* Mon Oct  6 2014 jengelh@inai.de
- Use implicit %%attrs; remove ancient specfile tags/sections
* Fri Feb 14 2014 meissner@suse.com
- actually enable the LDAP plugin. bnc#859625
* Tue Oct 22 2013 p.drouand@gmail.com
- Remove %%fillup_prereq %%insserv_prereq PreReq; the package doesn't
  contain any sysvinit script and sysconfig file
- Remove redundant %%clean section
* Mon Jul 29 2013 meissner@suse.com
- buildrequire pkg-config
* Mon Jul 29 2013 meissner@suse.com
- upgraded to 0.25 (FATE#312769)
  * nss_getpwnam: ignore case when comparing domain names
  * rpc.idmapd fails to load plugings
  * Cleaned up some warnings
  * Ignoring more files.
  * Improve debugging during lib initialization.
  * Added new --with-pluginpath configuration flag
- specify correct plugin searchpath to find plugins on lib64 systems
  bnc#800805
- fix-prototype.patch: updated to 0.25 state, dropped 2 upstream hunks
- libnfsidmap-export-symbols.patch: unfuzzed
* Sun Jan  1 2012 crrodriguez@opensuse.org
- On Dec 18 2010, export symbols patch was reverted, which is fine
  however we MUST still hide strlcpy() symbol as it will clash
  with other programs.
* Fri Nov 25 2011 aj@suse.de
- Upstream tarball is .gz, change source.
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Apr 27 2011 meissner@suse.de
- libnfsidmap-0.24
  * Added autogen.sh which runs all the autoconfig scripts
  * Added nfs4_owner interfaces which are used by the
    new nfsidmap program
* Wed Apr 27 2011 meissner@suse.de
- include manpage again bnc#689009
* Sat Dec 18 2010 cristian.rodriguez@opensuse.org
- revert the last change that exported only public symbols
  breaks loadable modules.
* Sat Dec 11 2010 cristian.rodriguez@opensuse.org
- libnfsidmap: export only public symbols nfs4_*, in particular
  this avoids exporting strlcpy to calling applications..
- openldap2-devel is not required in -devel package
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon Mar 29 2010 meissner@suse.de
- disable the idmapd.conf manpage inclusion, it is in nfs-utils.
* Wed Mar 24 2010 meissner@suse.de
- also remove .la files from the libnfsidmap subdir
- fixed missing ctype.h header include
* Fri Feb 26 2010 meissner@suse.de
- updated to 0.23
  * Allows mappings to be correct "right out of the box" when DNS is
    set up correctly and stops idmapper from dying when there is
    no domain name set.
  * Move the default processing for the "Local-Realm" config option
    into the main config file processing function and adds missing
    documentation for the previously added configuration option.
  * Print a debug log message "when the krb5 realm can not be used since
    it does not match the DNS domain name or the 'Local-Realm' variable
    defined in /etc/idmad.conf"
  * Move the idmapd.conf manpage from nfs-utils and update it to match
    the current functionality.
  * Changes to install, and look for, the plugin libraries in a separate
    libnfsidmap directory.
* Wed Apr 22 2009 meissner@suse.de
- move plugins .so files to main package, to make it work again
  bnc#495665, bnc#497209
- disable versioning of those plugin libs
* Mon Mar 30 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Mon Mar 16 2009 meissner@suse.de
- upgraded to 0.21
  - The main library has been changed to load "plugin" libraries to
  perform the mappings.  This decouples the main library from any ldap
  (and sasl, etc.) dependencies.
  - Several translation methods (plugins) may now be specified in the
  idmapd.conf file.  While a plugin returns -ENOENT, the next is called
  until a mapping is found, or there are no more plugins to try.
  - A "static" mapping plugin from David Härdeman <david@hardeman.nu> has
  been added.
  - A "gums" mapping plugin from Olga Kornievskaia <aglo@citi.umich.edu>
  has been added.
* Thu Jul 19 2007 meissner@suse.de
- upgraded to 0.20 (various bugfixes)
- fixed nfsv4 id mapping
- split up -devel package.
* Mon Jul 16 2007 ro@suse.de
- added nfsv4.schema from fate#301375
* Tue Aug  8 2006 ro@suse.de
- update to 0.16 (various bugfixes, no upstream changelog)
* Tue Apr 25 2006 okir@suse.de
- Stop adding ou=People to LDAP search string; now it
  works with eDirectory (#169152)
* Mon Mar 20 2006 okir@suse.de
- Do not crash if user is not in passwd database (#154912)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 okir@suse.de
- Updated to latest upstream version
* Tue Oct 18 2005 ro@suse.de
- added -DLDAP_DEPRECATED to CFLAGS
* Tue May 31 2005 okir@suse.de
- Initial packaging
